@@ -5,8 +5,8 @@ use rppal::{hal, i2c::I2c};
 
 fn main() {
     let mut delay = hal::Delay;
-    let mut ic = CharlieBonnet::configure(I2c::new().expect("Failed to load i2c bus"), &mut delay);
-    ic.setup().expect("Failed to setup IC");
+    let mut ic = CharlieBonnet::configure(I2c::new().expect("Failed to load i2c bus"));
+    ic.setup(&mut delay).expect("Failed to setup IC");
 
     for x in 0..16 {
         for y in 0..8 {
