@@ -5,9 +5,8 @@ pub mod devices;
 use embedded_hal::blocking::delay::DelayMs;
 use embedded_hal::blocking::i2c::Write;
 
-pub struct IS31FL3731<'a, I2C, DEL> {
+pub struct IS31FL3731<I2C> {
     pub i2c: I2C,
-    pub delay: &'a mut DEL,
     pub address: u8,
     pub frame: u8,
     pub width: u8,
@@ -15,10 +14,9 @@ pub struct IS31FL3731<'a, I2C, DEL> {
     pub calc_pixel: fn(x: u8, y: u8) -> u8,
 }
 
-impl<I2C, DEL, I2cError> IS31FL3731<'_, I2C, DEL>
+impl<I2C, I2cError> IS31FL3731<I2C>
 where
     I2C: Write<Error = I2cError>,
-    DEL: DelayMs<u8>,
 {
     pub fn fill(&mut self, brightness: u8, blink: Option<bool>, frame: u8) -> Result<(), I2cError> {
         self.bank(frame)?;
@@ -36,9 +34,9 @@ where
         Ok(())
     }
 
-    pub fn setup(&mut self) -> Result<(), I2cError> {
+    pub fn setup<DEL: DelayMs<u8>>(&mut self, delay: &mut DEL) -> Result<(), I2cError> {
         self.sleep(true)?;
-        self.delay.delay_ms(10);
+        delay.delay_ms(10);
         self.mode(addresses::PICTURE_MODE)?;
         self.frame(0)?;
         for frame in 0..8 {
@@ -74,9 +72,9 @@ where
         Ok(())
     }
 
-    pub fn reset(&mut self) -> Result<(), I2cError> {
+    pub fn reset<DEL: DelayMs<u8>>(&mut self, delay: &mut DEL) -> Result<(), I2cError> {
         self.sleep(true)?;
-        self.delay.delay_ms(10);
+        delay.delay_ms(10);
         self.sleep(false)?;
         Ok(())
     }
